pub enum SignPolicy {
Managed,
External,
}Expand description
Specifies how an added state-transition input should be signed.
Variants
Managed
The program (via Arch) manages signing responsibility for this input.
This applies when the signer has either:
- Already signed the transaction (e.g., fee payer or any other account that has signed)
- Will be signed by the program itself (e.g., program PDAs)
An InputToSign entry is recorded for Arch to handle the signature.
External
A third-party will provide the signature for this input.
This applies to accounts owned by other programs (e.g., via CPI) or signers
which have not signed this transaction. No InputToSign entry is recorded.