macro_rules! declare_fixed_array {
($Name:ident, $T:ty, $SIZE:expr) => { ... };
}Expand description
This macro declares a new array type for a specified type
macro_rules! declare_fixed_array {
($Name:ident, $T:ty, $SIZE:expr) => { ... };
}This macro declares a new array type for a specified type